<?php
// Prevent direct access to this file
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

/*
Plugin Name: Max Upload Size Changer
Description: Allows users to change the maximum upload size from the WordPress dashboard.
Version: 1.0
Author: Fortisthemes
Author URI: https://denis.swishfolio.com/
Text Domain: max-upload-size-changer
License: GPLv2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

// Add the plugin menu item
add_action('admin_menu', 'wpmusc_add_admin_menu');

function wpmusc_add_admin_menu()
{
    add_options_page(
        esc_html__('Max Upload Size Settings', 'max-upload-size-changer'),
        esc_html__('Max Upload Size', 'max-upload-size-changer'),
        'manage_options',
        'wp-max-upload-size-changer',
        'wpmusc_options_page'
    );
}

// Register plugin settings
add_action('admin_init', 'wpmusc_settings_init');

function wpmusc_settings_init()
{
    register_setting(
        'wpmusc_option_group',
        'wpmusc_max_upload_size',
        array(
            'type' => 'integer',
            'sanitize_callback' => 'wpmusc_sanitize_upload_size',
            'default' => 64
        )
    );
}

// Add sanitization callback function
function wpmusc_sanitize_upload_size($input)
{
    // Convert to integer and ensure it's positive
    $value = absint($input);

    // Set minimum value of 1MB
    if ($value < 1) {
        $value = 1;
    }

    // Set a reasonable maximum limit (6GB = 6144MB)
    if ($value > 6144) {
        $value = 6144;
    }

    return $value;
}

// Create the options page
function wpmusc_options_page()
{
    ?>
<div class="wrap">
    <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
    <form method="post" action="options.php">
        <?php
            settings_fields('wpmusc_option_group');
    do_settings_sections('wpmusc_option_group');
    ?>
        <table class="form-table">
            <tr valign="top">
                <th scope="row">
                    <?php esc_html_e('Max Upload Size (in MB)', 'max-upload-size-changer'); ?>
                </th>
                <td>
                    <input type="number" name="wpmusc_max_upload_size" step="20"
                        value="<?php echo esc_attr(get_option('wpmusc_max_upload_size', '64')); ?>" />
                </td>
            </tr>
        </table>
        <?php submit_button(); ?>
    </form>
    <h2><?php esc_html_e('Current Max Upload Size', 'max-upload-size-changer'); ?>
    </h2>
    <p>
        <?php
        echo esc_html(
            sprintf(
                /* translators: %s: Current maximum upload size */
                __('The current maximum upload size is: %s', 'max-upload-size-changer'),
                size_format(wp_max_upload_size())
            )
        );
    ?>
    </p>
    <p><strong><?php esc_html_e('Note:', 'max-upload-size-changer'); ?></strong>
        <?php esc_html_e('Changing the upload size here may not work if your server has stricter limits in place. Contact your hosting provider if you need to increase the limit beyond what\'s allowed here.', 'max-upload-size-changer'); ?>
    </p>
</div>
<?php
}

// Try to change the upload size limits
add_filter('upload_size_limit', 'wpmusc_change_upload_size', 20);

function wpmusc_change_upload_size($size)
{
    $desired_size = intval(get_option('wpmusc_max_upload_size', '64')) * 1024 * 1024; // Convert MB to bytes
    return min($desired_size, $size); // Return the smaller of the two to respect server limits
}

// Add a notice if the actual upload size is smaller than the desired size
add_action('admin_notices', 'wpmusc_admin_notice');

function wpmusc_admin_notice()
{
    $screen = get_current_screen();
    if ($screen->id != 'settings_page_wp-max-upload-size-changer') {
        return;
    }

    $desired_size = intval(get_option('wpmusc_max_upload_size', '64')) * 1024 * 1024;
    $actual_size = wp_max_upload_size();

    if ($actual_size < $desired_size) {
        ?>
<div class="notice notice-warning is-dismissible">
    <p>
        <?php
                echo esc_html(
                    sprintf(
                        /* translators: 1: Actual maximum upload size, 2: Desired maximum upload size */
                        __('The actual maximum upload size (%1$s) is smaller than your desired size (%2$s). This may be due to server limitations.', 'max-upload-size-changer'),
                        size_format($actual_size),
                        size_format($desired_size)
                    )
                );
        ?>
    </p>
</div>
<?php
    }
}
?>